<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\TypeParser;
use SimpleXMLIterator;

/**
 * IframelyParser
 * @package Infomaker\Everyware\NewsML\Parsers
 */
class IframelyParser implements ItemParser, TypeParser
{

    public const OBJECT_TYPE = 'x-im/iframely';

    public function parse(SimpleXMLIterator $element): array
    {
        $item = new Item($element);
        $links = [];

        foreach ($element->links->link as $link) {
            $links[] = [
                'url' => (string)$link->attributes()->url,
                'type' => (string)$link->attributes()->type,
                'data' => (array)$link->data
            ];
        }
        $item->fill([
            'content' => isset($element->data->embedCode) ? trim((string)$element->data->embedCode) : '',
            'links' => $links
        ]);

        return [$item];
    }

    public function typeToParse(): string
    {
        return static::OBJECT_TYPE;
    }
}
