<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\TypeParser;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use SimpleXMLIterator;

/**
 * ImageGalleryParser
 * @package Infomaker\Everyware\NewsML\Parsers
 */
class ImageGalleryParser implements ItemParser, TypeParser
{

    public const OBJECT_TYPE = 'x-im/imagegallery';

    /**
     * @var LinkParser
     */
    protected $linkParser;

    public function __construct()
    {
        $this->linkParser = new LinkParser([
            ImageLinkParser::LINK_TYPE => new ImageLinkParser()
        ]);
    }

    public function parse(SimpleXMLIterator $element): array
    {
        $item = new Item($element);
        $data = $item->getFirstChild('data');
        $item->fill([
            'type' => $item->getType(),
            'images' => $this->getImages($element),
            'caption' => $data instanceof Item ? $data->get('text') : ''
        ]);

        return [$item];
    }

    public function typeToParse(): string
    {
        return static::OBJECT_TYPE;
    }

    protected function getImages(SimpleXMLIterator $element): array
    {
        return array_filter($this->linkParser->parseLinks($element), static function (Item $item) {
            return $item->getType() === 'x-im/image';
        });
    }
}
