<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use SimpleXMLIterator;

class LinkParser
{

    /**
     * Contains a group of parsers
     *
     * @var ItemParser[]
     */
    private $parsers;

    public function __construct(array $parsers = [])
    {
        $this->parsers = $parsers;
    }

    public function getType(SimpleXMLIterator $el): string
    {
        $attributes = ((array)$el->attributes())['@attributes'] ?? [];

        return $attributes['type'] ?? '';
    }

    public function getLinkParser(SimpleXMLIterator $el): ?ItemParser
    {
        return $this->parsers[$this->getType($el)] ?? null;
    }

    public function parseLinks(SimpleXMLIterator $el): array
    {
        $links = [[]];
        if (isset($el->links->link)) {
            foreach ($el->links->link as $item) {
                $parser = $this->getLinkParser($item);
                $links[] = $parser instanceof ItemParser ? $parser->parse($item) : [new Item($item)];
            }
        }

        return array_merge(...$links);
    }
}
