<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\TypeParser;
use SimpleXMLIterator;

class PdfParser implements ItemParser, TypeParser
{

    public const OBJECT_TYPE = 'x-im/pdf';

    public function parse(SimpleXMLIterator $element): array
    {
        $item = new Item($element);
        $item->fill($this->getLinkAttributes($element));

        return [$item];
    }

    private function getLinkAttributes(SimpleXMLIterator $el): array
    {
        $links = (new LinkParser)->parseLinks($el);

        foreach ($links as $link) {
            if ($link->getType() === $this->typeToParse()) {
                return [
                    'title' => $this->getTitle($link),
                    'file' => $this->getFileName($link),
                    'url' => $this->createUrl($link),
                ];
            }
        }

        return [];
    }

    private function getFileName(Item $item): string
    {
        return str_replace('im://pdf/', '', (string)$item->getItemAttribute('uri'));
    }

    private function getTitle(Item $item): string
    {
        $data = $item->getFirstChild('data');

        if ( ! $data instanceof Item) {
            return '';
        }

        $text = $data->getFirstChild('text');

        return $text instanceof Item ? $text->getFilteredContent(['strong', 'em']) : '';
    }

    public function typeToParse(): string
    {
        return static::OBJECT_TYPE;
    }

    private function createUrl(Item $item): string
    {
        if ( ! defined('CF_PDF')) {
            error_log('CF_PDF is not defined and can therefore not serve PDFs');
            define('CF_PDF', '');
        }

        return CF_PDF . '/' . $this->getFileName($item);
    }
}
