<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\LinkParsers\FacebookPageLinkParser;
use Infomaker\Everyware\NewsML\LinkParsers\FacebookPostLinkParser;
use Infomaker\Everyware\NewsML\LinkParsers\FacebookVideoLinkParser;
use Infomaker\Everyware\NewsML\LinkParsers\InstagramLinkParser;
use Infomaker\Everyware\NewsML\LinkParsers\SoundcloudLinkParser;
use Infomaker\Everyware\NewsML\LinkParsers\TwitterLinkParser;
use Infomaker\Everyware\NewsML\LinkParsers\VimeoLinkParser;
use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\TypeParser;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use SimpleXMLIterator;

class SocialEmbedParser implements ItemParser, TypeParser
{
    public const OBJECT_TYPE = 'x-im/socialembed';

    /**
     * @var LinkParser
     */
    protected $linkParser;

    public function __construct()
    {
        $this->linkParser = new LinkParser([
            FacebookPageLinkParser::LINK_TYPE => new FacebookPageLinkParser(),
            FacebookPostLinkParser::LINK_TYPE => new FacebookPostLinkParser(),
            FacebookVideoLinkParser::LINK_TYPE => new FacebookVideoLinkParser(),
            InstagramLinkParser::LINK_TYPE => new InstagramLinkParser(),
            SoundcloudLinkParser::LINK_TYPE => new SoundcloudLinkParser(),
            TwitterLinkParser::LINK_TYPE => new TwitterLinkParser(),
            VimeoLinkParser::LINK_TYPE => new VimeoLinkParser()
        ]);
    }

    public function parse(SimpleXMLIterator $element): array
    {
        $item = new Item($element);
        $item->fill([
            'content' => $this->linkParser->parseLinks($element)
        ]);

        return [$item];
    }

    public function typeToParse(): string
    {
        return static::OBJECT_TYPE;
    }
}
