<?php

namespace Spec\Infomaker\Everyware\NewsML;

use Infomaker\Everyware\NewsML\Parsers\Metadata\ContactInfoParser;
use Infomaker\Everyware\NewsML\Parsers\MetaDataParser;
use PhpSpec\ObjectBehavior;
use Infomaker\Everyware\NewsML\NewsMLTransformer;
use Infomaker\Everyware\NewsML\Parsers\IdfParser;
use Infomaker\Everyware\NewsML\Parsers\PdfParser;
use Infomaker\Everyware\NewsML\Parsers\GroupParser;
use Infomaker\Everyware\NewsML\Parsers\ImageParser;
use Infomaker\Everyware\NewsML\Parsers\TableParser;
use Infomaker\Everyware\NewsML\Parsers\ObjectParser;
use Infomaker\Everyware\NewsML\Parsers\ReviewParser;
use Infomaker\Everyware\NewsML\Parsers\TeaserParser;
use Infomaker\Everyware\NewsML\Parsers\ElementParser;
use Infomaker\Everyware\NewsML\Parsers\YoutubeParser;
use Infomaker\Everyware\NewsML\Parsers\HtmlEmbedParser;
use Infomaker\Everyware\NewsML\Parsers\LinkObjectParser;
use Infomaker\Everyware\NewsML\Parsers\ContentPartParser;
use Infomaker\Everyware\NewsML\Parsers\SocialEmbedParser;
use Infomaker\Everyware\NewsML\Parsers\ImageGalleryParser;

class NewsMLTransformerSpec extends ObjectBehavior
{
    private $parsers;

    function let()
    {
        $this->parsers = [
            SocialEmbedParser::OBJECT_TYPE => new SocialEmbedParser(),
            TeaserParser::OBJECT_TYPE => new TeaserParser(),
            ImageParser::OBJECT_TYPE => new ImageParser(),
            ImageGalleryParser::OBJECT_TYPE => new ImageGalleryParser(),
            TableParser::OBJECT_TYPE => new TableParser(),
            ContentPartParser::OBJECT_TYPE => new ContentPartParser(new ElementParser()),
            ReviewParser::OBJECT_TYPE => new ReviewParser(new ElementParser()),
            LinkObjectParser::OBJECT_TYPE => new LinkObjectParser(),
            HtmlEmbedParser::OBJECT_TYPE => new HtmlEmbedParser(),
            PdfParser::OBJECT_TYPE => new PdfParser(),
            YoutubeParser::OBJECT_TYPE => new YoutubeParser()
        ];
        $elementParser = new ElementParser();
        $objectParser = new ObjectParser($this->parsers);
        $groupParser = new GroupParser($elementParser, $objectParser);
        $idfParser = new IdfParser($elementParser, $objectParser, $groupParser);

        $this->beConstructedWith($idfParser);
    }

    function it_is_initializable()
    {
        $this->shouldHaveType(NewsMLTransformer::class);
    }

    public function it_can_transform_idf()
    {
        $elementText = 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Dolorem earum magni quam sapiente similique voluptatibus? A aliquam aut beatae fugit, in repellendus vero. Aliquam pariatur possimus quae quibusdam ratione unde?';
        $xml = <<<xml
            <idf>
                <group>
                    <element id="paragraph-273ee570c1469bdf5badeea5f0524166" type="body">$elementText</element>
                    <object type="x-im/imagegallery" id="imagegallery-1d202026f6d7a8511eeaf522a366d74e">
                        <links>
                            <link rel="image" type="x-im/image"  uri="im://image/NygPCiTpwG3j0WItNRSc3a6AbY0.jpg" uuid="c965e053-6176-58ec-81ad-d2d4c778761c">
                                <data>
                                    <height>1109</height>
                                </data>
                            </link>
                        </links>
                    </object>
                    <object id="youtubeembed-520ee6fcf2b9d2376c41b89cf10d98d7" type="x-im/youtube" uri="https://www.youtube.com/watch?v=htqjcfSrQsA" url="https://www.youtube.com/watch?v=htqjcfSrQsA">
                        <data>
                            <start>0</start>
                        </data>
                        <links>
                            <link rel="alternate" title="Click link to view content" type="text/html" url="https://www.youtube.com/watch?v=htqjcfSrQsA">
                                <data>
                                    <context>Video</context>
                                    <provider>YouTube</provider>
                                </data>
                            </link>
                            <link rel="alternate" type="image/jpg" url="https://i.ytimg.com/vi/htqjcfSrQsA/hqdefault.jpg">
                                <data>
                                    <width>480</width>
                                    <height>360</height>
                                </data>
                            </link>
                        </links>
                    </object>
                </group>
            </idf>
xml;
        $this->validateXML($xml, [
            [
                'id' => 'paragraph-273ee570c1469bdf5badeea5f0524166',
                'type' => 'body',
                'content' => $elementText
            ],
            [
                'id' => 'imagegallery-1d202026f6d7a8511eeaf522a366d74e',
                'type' => 'x-im/imagegallery'
            ],
            [
                'id' => 'youtubeembed-520ee6fcf2b9d2376c41b89cf10d98d7',
                'type' => 'x-im/youtube'
            ]
        ]);

    }

    public function it_should_not_parse_unknown_types_of_objects()
    {
        $xml = <<<xml
            <idf>
                <group>
                    <object type="x-im/imagegallery" id="imagegallery-1d202026f6d7a8511eeaf522a366d74e">
                        <links>
                            <link rel="image" type="x-im/image"  uri="im://image/NygPCiTpwG3j0WItNRSc3a6AbY0.jpg" uuid="c965e053-6176-58ec-81ad-d2d4c778761c">
                                <data>
                                    <height>1109</height>
                                </data>
                            </link>
                        </links>
                    </object>
                    <object type="x-im/unknown" uri="https://www.youtube.com/watch?v=htqjcfSrQsA" url="https://www.youtube.com/watch?v=htqjcfSrQsA">
                        <data>
                            <start>0</start>
                        </data>
                        <links>
                            <link rel="alternate" title="Click link to view content" type="text/html" url="https://www.youtube.com/watch?v=htqjcfSrQsA">
                                <data>
                                    <context>Video</context>
                                    <provider>YouTube</provider>
                                </data>
                            </link>
                            <link rel="alternate" type="image/jpg" url="https://i.ytimg.com/vi/htqjcfSrQsA/hqdefault.jpg">
                                <data>
                                    <width>480</width>
                                    <height>360</height>
                                </data>
                            </link>
                        </links>
                    </object>
                </group>
            </idf>
xml;
        $this->transform($xml)->shouldContainItemType('x-im/imagegallery');
        $this->transform($xml)->shouldNotContainItemType('x-im/unknown');
    }

    public function it_can_parse_an_object()
    {
        $objectParser = new ObjectParser($this->parsers);

        $this->beConstructedWith($objectParser);
        $xml = '
            <object type="x-im/link" id="contentrelations-c0580e5c1a9fac463b6989b2bc48fb10" title="" uuid="54db7504-cb51-4a1a-8c62-137e465e65ba">
                <links>
                    <link rel="self" type="x-im/article" uuid="54db7504-cb51-4a1a-8c62-137e465e65ba">
                    </link>
                </links>
            </object>';
        $this->transform($xml)->shouldContainItemType('x-im/article');
    }

    public function it_can_parse_metadata()
    {
        $parser = new MetaDataParser(
            new ObjectParser([
                ContactInfoParser::OBJECT_TYPE => new ContactInfoParser()
            ])
        );

        $this->beConstructedWith($parser);
        $xml = <<<XML
<metadata>
    <object type="x-im/contact-info">
        <data>
            <email>test@mail.com</email>
            <phone>111222333</phone>
            <mobile>444555666</mobile>
        </data>
    </object>
</metadata>
XML;

        $this->transform($xml)->shouldContainItemType('x-im/contact-info');
    }

    public function it_should_not_parse_metadata_with_unknown_type()
    {
        $parser = new MetaDataParser(new ObjectParser($this->parsers));

        $this->beConstructedWith($parser);
        $xml = <<<XML
<metadata>
    <object type="x-im/unknown">
        <data>
            <email>test@mail.com</email>
        </data>
    </object>
</metadata>
XML;

        $this->transform($xml)->shouldNotContainItemType('x-im/unknown');
    }

    protected function validateXML($xml, array $matchValues): void
    {
        $this->transform($xml)->shouldReturnValidItemCollection($matchValues);
    }
}
