<?php

namespace Spec\Infomaker\Everyware\NewsML\Objects;

use Infomaker\Everyware\NewsML\Interfaces\ItemWithImage;
use Infomaker\Everyware\NewsML\Interfaces\ItemWithLinks;
use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Objects\ImageItem;
use Infomaker\Everyware\NewsML\Objects\TeaserItem;
use PhpSpec\ObjectBehavior;
use Tightenco\Collect\Contracts\Support\Arrayable;

class TeaserItemSpec extends ObjectBehavior
{
    private $defaultAttributes = [
        'id' => 'MjE5LDE2MywyNDgsMjA4',
        'type' => 'x-im/teaser',
        'title' => 'Lorem ipsum dolor sit',
    ];

    public function let(): void
    {
        $xml = <<<XML
<object
    id="{$this->defaultAttributes['id']}"
    type="{$this->defaultAttributes['type']}"
    title="{$this->defaultAttributes['title']}"
/>
XML;

        $this->beConstructedWith(simplexml_load_string($xml, 'SimpleXMLIterator'));
    }

    public function it_is_initializable(): void
    {
        $this->shouldHaveType(Item::class);
        $this->shouldHaveType(TeaserItem::class);
    }

    public function it_should_implement_correct_interfaces()
    {
        $this->shouldImplement(Arrayable::class);
        $this->shouldImplement(ItemWithImage::class);
        $this->shouldImplement(ItemWithLinks::class);
    }

    public function it_should_return_list_of_links(Item $item)
    {
        $linkList = [$item];

        $this->set('links', $linkList);
        $this->getLinks()->shouldReturn($linkList);
    }

    public function it_should_return_empty_list_of_links_if_not_set()
    {
        $this->getLinks()->shouldReturn([]);
    }

    public function it_can_determine_if_a_teaser_has_links(Item $item)
    {
        $this->hasLinks()->shouldBe(false);

        $this->set('links', []);
        $this->hasLinks()->shouldBe(false);

        $this->set('links', [$item]);
        $this->hasLinks()->shouldBe(true);
    }

    public function it_should_extract_image_from_links(ImageItem $image)
    {
        $this->getImage()->shouldReturn(null);

        $this->set('links', [$image]);
        $this->getImage()->shouldReturn($image);
    }

    public function it_can_determine_if_a_teaser_has_an_image(Item $item, ImageItem $image)
    {
        $this->hasImage()->shouldBe(false);

        $this->set('links', [$item, 'Not ' . ImageItem::class]);
        $this->hasImage()->shouldBe(false);

        $this->set('links', [$image]);
        $this->hasImage()->shouldBe(true);
    }
}
