<?php
/** @noinspection PhpUnused */
/** @noinspection PhpUndefinedMethodInspection */
/** @noinspection AccessModifierPresentedInspection */
/** @noinspection ReturnTypeCanBeDeclaredInspection */

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\IdfParser;
use Infomaker\Everyware\NewsML\Parsers\ElementParser;
use Infomaker\Everyware\NewsML\Parsers\ImageGalleryParser;
use Infomaker\Everyware\NewsML\Parsers\ObjectParser;
use Infomaker\Everyware\NewsML\Parsers\ImageParser;
use Infomaker\Everyware\NewsML\Parsers\ContentPartParser;
use Infomaker\Everyware\NewsML\Parsers\GroupParser;
use Infomaker\Everyware\NewsML\Parsers\TeaserParser;
use Infomaker\Everyware\NewsML\Parsers\LinkObjectParser;
use Infomaker\Everyware\NewsML\Parsers\ReviewParser;
use Infomaker\Everyware\NewsML\Parsers\PdfParser;
use Infomaker\Everyware\NewsML\Parsers\YoutubeParser;
use Infomaker\Everyware\NewsML\Parsers\HtmlEmbedParser;
use Infomaker\Everyware\NewsML\Parsers\TableParser;
use Infomaker\Everyware\NewsML\Parsers\SocialEmbedParser;
use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Objects\ImageItem;
use Spec\Infomaker\Everyware\NewsML\CollectionParserSpec;

class IdfParserSpec extends CollectionParserSpec
{
    function let()
    {
        $objectParsers = [
            ImageGalleryParser::OBJECT_TYPE => new ImageGalleryParser()
        ];
        $this->beConstructedWith(new ElementParser(), new ObjectParser($objectParsers),
            new GroupParser(new ElementParser(), new ObjectParser($objectParsers)));
    }

    function it_is_initializable()
    {
        $this->shouldHaveType(IdfParser::class);
    }

    public function it_should_parse_a_group()
    {
        $xml = <<<XML
<idf>
    <group>
        <element id="paragraph-273ee570c1469bdf5badeea5f0524166" type="headline"><strong>Strong Headline</strong></element>
        <object type="x-im/imagegallery" id="imagegallery-1d202026f6d7a8511eeaf522a366d74e">
            <links>
                <link rel="image" type="x-im/image"  uri="im://image/NygPCiTpwG3j0WItNRSc3a6AbY0.jpg" uuid="c965e053-6176-58ec-81ad-d2d4c778761c">
                    <data>
                        <height>1109</height>
                    </data>
                </link>
            </links>
        </object>
    </group>
</idf>
XML;

        $this->validateXML($xml, [
            [
                'type' => 'headline',
                'content' => '<strong>Strong Headline</strong>'
            ],
            [
                'type' => 'x-im/imagegallery'
            ]
        ]);
    }

    public function it_should_parse_an_element()
    {

        $xml = <<<XML
<idf>
    <element id="paragraph-273ee570c1469bdf5badeea5f0524166" type="headline"><strong>Strong Headline</strong></element>
</idf>
XML;

        $this->validateXML($xml, [
            [
                'type' => 'headline',
                'content' => '<strong>Strong Headline</strong>'
            ]
        ]);
    }

    public function it_should_parse_an_object()
    {
        $xml = <<<XML
<idf>
    <object type="x-im/imagegallery" id="imagegallery-1d202026f6d7a8511eeaf522a366d74e">
        <links>
            <link rel="image" type="x-im/image"  uri="im://image/NygPCiTpwG3j0WItNRSc3a6AbY0.jpg" uuid="c965e053-6176-58ec-81ad-d2d4c778761c">
                <data>
                    <height>1109</height>
                </data>
            </link>
        </links>
    </object>
</idf>
XML;
        $this->validateXML($xml, [
            [
                'type' => 'x-im/imagegallery'
            ]
        ]);
    }
}
