<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\ImageGalleryParser;
use Infomaker\Everyware\Support\Format;
use Spec\Infomaker\Everyware\NewsML\ParserSpec;

class ImageGalleryParserSpec extends ParserSpec
{
    function it_is_initializable()
    {
        $this->shouldHaveType(ImageGalleryParser::class);
    }

    public function it_should_parse_an_object()
    {
        $xml = <<<XML
<object id="imagegallery-8a52dde8c22e270f0023d2060b0128b4" type="x-im/imagegallery" uuid="c51d19ff-cc44-4788-b1d7-0eb394f9b7f2">
    <data>
        <text>In sodales lectus vel egestas rhoncus</text>
    </data>
    <links>
        <link rel="image" type="x-im/image" uri="im://image/znX8U1CU124n26zu7gb40_jBzSk.jpeg" uuid="c382c937-8511-5d48-9677-55658c2bbb32">
            <data>
                <text>Image caption</text>
                <height>200</height>
                <width>400</width>
                <flags>
                    <flag>disableAutomaticCrop</flag>
                </flags>
            </data>
            <links>
                <link rel="crop" type="x-im/crop" title="16:9" uri="im://crop/0/0/1/1"/>
                <link rel="crop" type="x-im/crop" title="3:2" uri="im://crop/0.07875/0/0.84375/1"/>
                <link rel="crop" type="x-im/crop" title="2:3" uri="im://crop/0.3125/0/0.375/1"/>

                <link rel="focal-point" type="x-im/focal-point">
                    <data>
                        <x>123</x>
                        <y>456</y>
                    </data>
                </link>

                <link rel="author" uuid="7a39b42b-1315-4711-a136-7b3a9f132110" title="Demo Demosson" type="x-im/author">
                    <data>
                        <email>demo.demosson@infomaker.se</email>
                    </data>
                </link>
            </links>
        </link>
    </links>
</object>
XML;
        $this->validateXML($xml, [
            'id' => 'imagegallery-8a52dde8c22e270f0023d2060b0128b4',
            'type' => 'x-im/imagegallery',
            'uuid' => 'c51d19ff-cc44-4788-b1d7-0eb394f9b7f2',
            'caption' => 'In sodales lectus vel egestas rhoncus',
            'images' => [
                [
                    'rel' => 'image',
                    'type' => 'x-im/image',
                    'uri' => 'im://image/znX8U1CU124n26zu7gb40_jBzSk.jpeg',
                    'uuid' => 'c382c937-8511-5d48-9677-55658c2bbb32',
                    'text' => 'Image caption',
                    'width' => '400',
                    'height' => '200',
                    'authors' => [
                        [
                            'title' => 'Demo Demosson',
                            'uuid' => '7a39b42b-1315-4711-a136-7b3a9f132110',
                            'email' => 'demo.demosson@infomaker.se'
                        ]
                    ],
                    'crop' => [
                        '16:9' => [
                            'x' => Format::formatNumberToImengineFloat(0),
                            'y' => Format::formatNumberToImengineFloat(0),
                            'width' => Format::formatNumberToImengineFloat(1),
                            'height' => Format::formatNumberToImengineFloat(1),
                        ],
                        '3:2' => [
                            'x' => Format::formatNumberToImengineFloat(0.07875),
                            'y' => Format::formatNumberToImengineFloat(0),
                            'width' => Format::formatNumberToImengineFloat(0.84375),
                            'height' => Format::formatNumberToImengineFloat(1),
                        ],
                        '2:3' => [
                            'x' => Format::formatNumberToImengineFloat(0.3125),
                            'y' => Format::formatNumberToImengineFloat(0),
                            'width' => Format::formatNumberToImengineFloat(0.375),
                            'height' => Format::formatNumberToImengineFloat(1),
                        ],
                    ],
                    'flags' => [
                        ['name' => 'disableAutomaticCrop']
                    ],
                    'focal-point' => [
                        ['x' => '123', 'y' => '456']
                    ]
                ]
            ]
        ]);
    }

    public function it_should_have_default_values()
    {
        $xml = <<<XML
    <object id="im-imagegallery-121d0596d7c0161056159b69be99092c" type="x-im/imagegallery" uuid="1a1cba5a-7d79-4642-bef9-51012db143ed"/>
XML;

        $this->validateXML($xml, [
            'id' => 'im-imagegallery-121d0596d7c0161056159b69be99092c',
            'type' => 'x-im/imagegallery',
            'uuid' => '1a1cba5a-7d79-4642-bef9-51012db143ed',
            'images' => [],
            'caption' => '',
        ]);
    }

    public function it_should_return_its_type()
    {
        $this->typeToParse()->shouldReturn('x-im/imagegallery');
    }
}
