<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\PdfParser;
use Spec\Infomaker\Everyware\NewsML\ParserSpec;

class PdfParserSpec extends ParserSpec
{
    function it_is_initializable()
    {
        $this->shouldHaveType(PdfParser::class);
    }

    public function it_should_parse_an_object()
    {
        $xml = <<<XML
<object id="MjIxLDExNywyMzMsMTg" uuid="05bfe2e4-3666-5466-90bb-2997e6a9f0ef" type="x-im/pdf">
    <links>
        <link rel="self" type="x-im/pdf" uri="im://pdf/WwPM7He0FoBdbY4nDTOUKq7cxt0.pdf" uuid="05bfe2e4-3666-5466-90bb-2997e6a9f0ef">
            <data>
                <text>Lorem ipsum text</text>
                <title>Lorem ipsum title</title>
                <objectName>Lorem-ipsum.pdf</objectName>
            </data>
        </link>
    </links>
</object>
XML;

        $this->validateXML($xml, [
            'id' => 'MjIxLDExNywyMzMsMTg',
            'uuid' => '05bfe2e4-3666-5466-90bb-2997e6a9f0ef',
            'type' => 'x-im/pdf',
            'title' => 'Lorem ipsum text',
            'file' => 'WwPM7He0FoBdbY4nDTOUKq7cxt0.pdf',
            'url' => CF_PDF . '/WwPM7He0FoBdbY4nDTOUKq7cxt0.pdf',
        ]);
    }

    public function it_should_parse_an_empty_object()
    {
        $xml = '<object id="MjIxLDExNywyMzMsMTg" uuid="05bfe2e4-3666-5466-90bb-2997e6a9f0ef" type="x-im/pdf"/>';
        $this->validateXML($xml, [
            'id' => 'MjIxLDExNywyMzMsMTg',
            'uuid' => '05bfe2e4-3666-5466-90bb-2997e6a9f0ef',
            'type' => 'x-im/pdf',
        ]);
    }

    public function it_should_support_parsing_of_annotations_in_the_title()
    {
        $text = <<<TEXT
<strong id="strong-00421cfcbbb61c85b0318309541f84be">
    <em id="emphasis-b6447ce0314152526e1024f6e7e3067f">pdf-test.pdf</em>
</strong>
TEXT;

        $xml = <<<XML
<object id="MjIxLDExNywyMzMsMTg" uuid="05bfe2e4-3666-5466-90bb-2997e6a9f0ef" type="x-im/pdf">
    <links>
        <link rel="self" type="x-im/pdf" uri="im://pdf/WwPM7He0FoBdbY4nDTOUKq7cxt0.pdf" uuid="05bfe2e4-3666-5466-90bb-2997e6a9f0ef">
            <data>
                <text>$text</text>
            </data>
        </link>
    </links>
</object>
XML;

        $this->validateXML($xml, [
            'title' => $this->concatenateXML($text),
        ]);
    }

    public function it_should_return_its_type()
    {
        $this->typeToParse()->shouldReturn('x-im/pdf');
    }
}
