<?php

namespace Spec\Matchers;

use PhpSpec\Matcher\BasicMatcher;
use PhpSpec\Exception\Example\FailureException;

class KeysValues extends BasicMatcher
{
    private $names = [
        'beKeysValues',
        'haveKeysValues',
        'beValuesKeys',
        'haveValuesKeys',
    ];

    /**
     * @throws FailureException
     */
    protected function matches($subject, array $arguments): bool
    {
        $expects = (array)$arguments[0];
        $result = array_filter((array)$subject);

        foreach ($expects as $key => $value) {

            if ( ! array_key_exists($key, $result)) {
                throw new FailureException(
                    sprintf('Missing key: "%s"', $key)
                );
            }

            if ($result[$key] !== $value) {
                throw new FailureException(implode(PHP_EOL, [
                    sprintf('Key: "%s" does not match the desired value.', $key),
                    'expected ',
                    json_encode($value, JSON_PRETTY_PRINT),
                    'but got ',
                    json_encode($result[$key], JSON_PRETTY_PRINT)
                ]));
            }
        }

        return $result === $expects;
    }

    protected function getFailureException(string $name, $subject, array $arguments): FailureException
    {
        return new FailureException(
            implode(PHP_EOL, [
                'expected',
                json_encode($arguments[0] ?? 'empty'),
                'but got ',
                json_encode($subject)
            ])
        );
    }

    protected function getNegativeFailureException(string $name, $subject, array $arguments): FailureException
    {
        return $this->getFailureException($name, $subject, $arguments);
    }

    public function supports(string $name, $subject, array $arguments): bool
    {
        return in_array($name, $this->names)
            && count($arguments) === 1
            && is_array($arguments[0]);
    }
}
